@@ -1,11 +1,16 @@
+from django.contrib.contenttypes.models import ContentType
+from drf_yasg.utils import swagger_serializer_method
 from rest_framework import serializers
 
 from dcim.api.nested_serializers import NestedPlatformSerializer
+from netbox.api.fields import ContentTypeField
 from netbox.api.serializers import NetBoxModelSerializer
+from netbox.constants import NESTED_SERIALIZER_PREFIX
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
     NestedMountedVolumeSerializer, NestedDeviceSerializer, NestedVolumeGroupSerializer
 from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, StorageConfigurationDrive, \
     LinuxDevice, TemplateConfigurationDrive, PhysicalVolume, VolumeGroup, LogicalVolume
+from utilities.api import get_serializer_for_model
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -81,6 +86,10 @@ class MountedVolumeSerializer(serializers.ModelSerializer):
 
 
 class LinuxDeviceSerializer(serializers.ModelSerializer):
+    content_type = ContentTypeField(
+        queryset=ContentType.objects.all()
+    )
+    object = serializers.SerializerMethodField(read_only=True)
 
     class Meta:
         model = LinuxDevice
@@ -89,14 +98,21 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
             "device",
             "type",
             "size",
+            'content_type', 'object_id', 'object',
             "created",
             "last_updated",
             "custom_fields",
         )
 
+    @swagger_serializer_method(serializer_or_field=serializers.JSONField)
+    def get_object(self, instance):
+        serializer = get_serializer_for_model(instance.content_type.model_class(), prefix=NESTED_SERIALIZER_PREFIX)
+        context = {'request': self.context['request']}
+        return serializer(instance.object, context=context).data
+
 
 class PhysicalVolumeSerializer(serializers.ModelSerializer):
-    device = NestedDeviceSerializer(required=False, allow_null=True)
+    linux_device = NestedDeviceSerializer(required=False, allow_null=True)
     vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
 
     class Meta:
